@@ -55,7 +55,8 @@
 #'     \item{normaTest} { The results of the residuals normality test}
 #'     \item{homoTest} { The results of the residuals homogeneity test}
 #'     \item{observed_shape} { The observed shape of the model fit}
-#'     \item{asymptote} { A logical value indicating whether the observed fit is asymptotic}}
+#'     \item{asymptote} { A logical value indicating whether the observed fit is asymptotic}
+#'     \item{neg_check} { A logical value indicating whether negative fitted values have been returned}}
 
 #'   The \code{\link{summary.sars}} function returns a more useful summary of
 #'   the model fit results, and the \code{\link{plot.sars}} plots the model fit.
@@ -113,6 +114,7 @@ if(is.na(fit$value)){
   obs <- obs_shape(fit)
   fit$observed_shape <- obs$fitShape
   fit$asymptote <- obs$asymp
+  fit$neg_check <- any(fit$calculated < 0)
   class(fit) <- 'sars'
   attr(fit, 'type') <- 'fit'
   return(fit)
